==> libswirl-java_1.0.13.orig.tar.gz: swirl-1.0.13/be/ugent/caagt/swirl/subwindows/SubwindowListener.java <==
/* SubwindowListener.java
 * =========================================================================
 * This file is part of the SWIRL Library - http://swirl-lib.sourceforge.net
 *
 * Copyright (C) 2005-2007 Universiteit Gent
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 *
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 *
 */

package be.ugent.caagt.swirl.subwindows;

import java.util.EventListener;

/**
 * Listens to changes in the state of a subwindow.
 */
public interface SubwindowListener extends EventListener {
    
    /**
     * Called when the collapsed state of the subwindow changes.
     * @param subwindow subwindow which changed state
     * @param collapsed indicates whether the subwindow has just been collapsed
     */
    public void changedCollapsedState (Subwindow subWindow, boolean collapsed);
    
}

==> libswirl-java_1.1.orig.tar.gz: swirl-1.1/be/ugent/caagt/swirl/subwindows/SubwindowListener.java <==
/* SubwindowListener.java
 * =========================================================================
 * This file is part of the SWIRL Library - http://swirl-lib.sourceforge.net
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 * 
 */

package be.ugent.caagt.swirl.subwindows;

import java.util.EventListener;

/**
 * Listens to changes in the state of a subwindow.
 */
public interface SubwindowListener extends EventListener {
    
    /**
     * Called when the collapsed state of the subwindow changes.
     * @param subwindow subwindow which changed state
     * @param collapsed indicates whether the subwindow has just been collapsed
     */
    public void changedCollapsedState (Subwindow subwindow, boolean collapsed);
    
}
